@@ -1,11 +1,11 @@
-from mite.scenario import StopScenario
+from mite.scenario import StopVolumeModel
 from mite_http import mite_http
 
 
 def volume_model_factory(n):
     def vm(start, end):
         if start > 60 * 1:
-            raise StopScenario
+            raise StopVolumeModel
         return n
     vm.__name__ = f"volume model {n}"
     return vm
